@@ -1,7 +1,7 @@
 package Complete::Getopt::Long;
 
-our $DATE = '2015-02-15'; # DATE
-our $VERSION = '0.29'; # VERSION
+our $DATE = '2015-03-04'; # DATE
+our $VERSION = '0.30'; # VERSION
 
 use 5.010001;
 use strict;
@@ -33,7 +33,7 @@ sub _default_completion {
             my $compres = Complete::Util::complete_env(
                 word=>$word);
             last unless @$compres;
-            $fres = {words=>$compres, escmode=>'shellvar'};
+            $fres = {words=>$compres, esc_mode=>'shellvar'};
             goto RETURN_RES;
         }
         # if empty, fallback to searching file
@@ -511,7 +511,7 @@ sub complete_cli_arg {
                          'matching options=%s', $compres);
         push @res, @$compres;
         if (!exists($exp->{optval}) && !exists($exp->{arg})) {
-            $fres = {words=>\@res, escmode=>'option'};
+            $fres = {words=>\@res, esc_mode=>'option'};
             goto RETURN_RES;
         }
     }
@@ -600,7 +600,7 @@ Complete::Getopt::Long - Complete command-line argument using Getopt::Long speci
 
 =head1 VERSION
 
-This document describes version 0.29 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2015-02-15.
+This document describes version 0.30 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2015-03-04.
 
 =head1 SYNOPSIS
 
@@ -766,7 +766,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-G
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Complete-Getopt-Long>.
+Source repository is at L<https://github.com/perlancar/perl-Complete-Getopt-Long>.
 
 =head1 BUGS
 
